==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Information/InfoArea/ts/InfoArea_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>InfoArea</name>
    <message>
        <location filename="../InfoArea.js" line="+70"/>
        <source>Set next polygon corner</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Ustaw następny róg wielokąta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation type="unfinished">Zrobione</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>Polygon area:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Polygon area:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>circumference:</source>
        <translatorcomment>--google--
Obwód: %1</translatorcomment>
        <translation type="unfinished">obwód:</translation>
    </message>
    <message>
        <location filename="../InfoArea.ui" line="+17"/>
        <source>Calculate length and close tool.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Oblicz długość i zamknij narzędzie.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Close Tool.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zamknij Tool.</translation>
    </message>
    <message>
        <location filename="../InfoAreaInit.js" line="+2"/>
        <source>Pol&amp;ygonal Area</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Obszar wielokątne</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Information/InfoArea/ts/InfoArea_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>InfoArea</name>
    <message>
        <location filename="../InfoArea.js" line="+70"/>
        <source>Set next polygon corner</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać następny narożnik wielokąta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation>Zrobione</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>Polygon area:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Pole wielokąta:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>circumference:</source>
        <translatorcomment>--google--
Obwód: %1</translatorcomment>
        <translation>obwód:</translation>
    </message>
    <message>
        <location filename="../InfoArea.ui" line="+17"/>
        <source>Calculate length and close tool.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Oblicz długość i zamknij narzędzie.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Close Tool.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zamknij narzędzie.</translation>
    </message>
    <message>
        <location filename="../InfoAreaInit.js" line="+2"/>
        <source>Pol&amp;ygonal Area</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Pole wie&amp;loboku</translation>
    </message>
</context>
</TS>
